==> xfmail_1.2p0.orig.tar.gz: xfmail-1.2/ui/int_conf.c <==
/*
 * Copyright(c) 1995,1996 by Gennady B. Sorokopud (gena@NetVision.net.il)
 *
 * This software can be freely redistributed and modified for 
 * non-commercial purposes as long as above copyright
 * message and this permission notice appear in all
 * copies of distributed source code and included as separate file
 * in binary distribution.
 *
 * Any commercial use of this software requires author's permission.
 *
 * This software is provided "as is" without expressed or implied
 * warranty of any kind.
 * Under no circumstances is the author responsible for the proper
 * functioning of this software, nor does the author assume any
 * responsibility for damages incurred with its use.
 *
 */

/* $Id: mime_conf.c,v 1.10 1995/11/03 15:19:24 gena Exp $
 */

#include <fmail.h>
#include <umail.h>
#include <choose_folder.h>
#include "configform.h"

static FD_config_intern *int_obj;

void
Int_Call(obj, param)
FL_OBJECT *obj;
long param;
{
}

void
Int_7bit_Call(obj, param)
FL_OBJECT *obj;
long param;
{
 fl_set_choice(int_obj->Int_ChSet, 1);
}

void
Int_ChSet_Call(obj, param)
FL_OBJECT *obj;
long param;
{
 if (fl_get_choice(int_obj->Int_ChSet) == 1) {
  fl_set_button(int_obj->Int_7bit, 1);
  fl_set_button(int_obj->Int_8bit, 0);
  fl_set_button(int_obj->Int_qprt, 0);	     }
}

void
int_conf(int set_default, FD_config_intern *form)
{
int k, chline;
char chdescr[32];

 int_obj = form;

 k = 0;
 chline = -1;
 fl_clear_choice(int_obj->Int_ChSet);
 while (supp_charsets[k].charset_code != CHAR_UNKNOWN)  {
        if (is_charset_alias(supp_charsets[k].charset_name)) {
                k++;
                continue;
                }

	sprintf(chdescr, "%s (%s)", supp_charsets[k].charset_name, supp_charsets[k].charset_descr);
	fl_addto_choice(int_obj->Int_ChSet, chdescr);
	if (def_charset == k)
		chline = fl_get_choice_maxitems(int_obj->Int_ChSet);
	k++;
							}

 if (chline == -1) {
	def_charset = DEFAULT_CHARSET;
	fl_set_choice(int_obj->Int_ChSet, 1);
		}
 else
	fl_set_choice(int_obj->Int_ChSet, chline);

 switch (supp_encodings[def_encoding].c_trans_enc) 	{
   case CE_7BIT:
	fl_set_button(int_obj->Int_7bit, 1);
   break;

   case CE_8BIT:
	fl_set_button(int_obj->Int_8bit, 1);
   break;

   case CE_QPRT:
	fl_set_button(int_obj->Int_qprt, 1);
   break;

   default:
	fl_set_button(int_obj->Int_8bit, 1);
	def_encoding = DEFAULT_ENCODING;
   break;
							}

 fl_set_button(int_obj->Int_Header, b_getcfg_int_default(conf_name, "encheader", 1, set_default));
}

void
handle_intern_input(FD_config_intern *form)
{
int k, chline;

 int_obj = form;
 
 k = 0;
 chline = 0;
 while (supp_charsets[k].charset_code != CHAR_UNKNOWN)  {
        if (is_charset_alias(supp_charsets[k].charset_name)) {
                k++;
                continue;
                }

	chline++;
	if (chline == fl_get_choice(int_obj->Int_ChSet)) {
		def_charset = k;
		b_putcfg_int(conf_name, "charset", k);
		break;
							}
	k++;
								}

 if (fl_get_button(int_obj->Int_7bit)) 	{
	if (def_charset != DEFAULT_CHARSET) {
	 display_msg(MSG_WARN, "International", "7bit can not be used with %s, swithing to US-ASCII", supp_charsets[def_charset].charset_name);
	 def_charset = DEFAULT_CHARSET;	    }
	chline = CE_7BIT;		}
 else
 if (fl_get_button(int_obj->Int_qprt))
	chline = CE_QPRT;
 else
	chline = CE_8BIT;

 k = 0;
 while (supp_encodings[k].c_trans_enc != CE_UNSUPPORTED) {
	if (supp_encodings[k].c_trans_enc == chline) {
		def_encoding = k;
		b_putcfg_int(conf_name, "encoding", k);
		break;
							}
	k++;
							 }

 b_putcfg_int(conf_name, "encheader", fl_get_button(int_obj->Int_Header));
}

==> xfmail_1.3p0-1.tar.gz: xfmail-1.3/ui/int_conf.c <==
/*
 * Copyright(c) 1995-1998 by Gennady B. Sorokopud (gena@NetVision.net.il)
 *
 * This software can be freely redistributed and modified for 
 * non-commercial purposes as long as above copyright
 * message and this permission notice appear in all
 * copies of distributed source code and included as separate file
 * in binary distribution.
 *
 * Any commercial use of this software requires author's permission.
 *
 * This software is provided "as is" without expressed or implied
 * warranty of any kind.
 * Under no circumstances is the author responsible for the proper
 * functioning of this software, nor does the author assume any
 * responsibility for damages incurred with its use.
 *
 */

/* $Id: mime_conf.c,v 1.10 1995/11/03 15:19:24 gena Exp $
 */

#include <fmail.h>
#include <umail.h>
#include <choose_folder.h>
#include "configform.h"

static FD_config_intern *int_obj;

void
Int_Call(obj, param)
FL_OBJECT *obj;
long param;
{
}

void
Int_7bit_Call(obj, param)
FL_OBJECT *obj;
long param;
{
 fl_set_choice(int_obj->Int_ChSet, 1);
}

void
Int_ChSet_Call(obj, param)
FL_OBJECT *obj;
long param;
{
 if (fl_get_choice(int_obj->Int_ChSet) == 1) {
  fl_set_button(int_obj->Int_7bit, 1);
  fl_set_button(int_obj->Int_8bit, 0);
  fl_set_button(int_obj->Int_qprt, 0);	     }
}

void
int_conf(int set_default, FD_config_intern *form)
{
int k, chline;
char chdescr[32];

 int_obj = form;

 k = 0;
 chline = -1;
 fl_clear_choice(int_obj->Int_ChSet);
 while (supp_charsets[k].charset_code != CHAR_UNKNOWN)  {
        if (is_charset_alias(supp_charsets[k].charset_name)) {
                k++;
                continue;
                }

	snprintf(chdescr, sizeof(chdescr), "%s (%s)", supp_charsets[k].charset_name, supp_charsets[k].charset_descr);
	fl_addto_choice(int_obj->Int_ChSet, chdescr);
	if (def_charset == k)
		chline = fl_get_choice_maxitems(int_obj->Int_ChSet);
	k++;
							}

 if (chline == -1) {
	def_charset = DEFAULT_CHARSET;
	fl_set_choice(int_obj->Int_ChSet, 1);
		}
 else
	fl_set_choice(int_obj->Int_ChSet, chline);

 switch (supp_encodings[def_encoding].c_trans_enc) 	{
   case CE_7BIT:
	fl_set_button(int_obj->Int_7bit, 1);
   break;

   case CE_8BIT:
	fl_set_button(int_obj->Int_8bit, 1);
   break;

   case CE_QPRT:
	fl_set_button(int_obj->Int_qprt, 1);
   break;

   default:
	fl_set_button(int_obj->Int_8bit, 1);
	def_encoding = DEFAULT_ENCODING;
   break;
							}

 fl_set_button(int_obj->Int_Header, b_getcfg_int_default(conf_name, "encheader", 1, set_default));
}

void
handle_intern_input(FD_config_intern *form)
{
int k, chline;

 int_obj = form;
 
 k = 0;
 chline = 0;
 while (supp_charsets[k].charset_code != CHAR_UNKNOWN)  {
        if (is_charset_alias(supp_charsets[k].charset_name)) {
                k++;
                continue;
                }

	chline++;
	if (chline == fl_get_choice(int_obj->Int_ChSet)) {
		def_charset = k;
		b_putcfg_int(conf_name, "charset", k);
		break;
							}
	k++;
								}

 if (fl_get_button(int_obj->Int_7bit)) 	{
	if (def_charset != DEFAULT_CHARSET) {
	 display_msg(MSG_WARN, "International", "7bit can not be used with %s, swithing to US-ASCII", supp_charsets[def_charset].charset_name);
	 def_charset = DEFAULT_CHARSET;	    }
	chline = CE_7BIT;		}
 else
 if (fl_get_button(int_obj->Int_qprt))
	chline = CE_QPRT;
 else
	chline = CE_8BIT;

 k = 0;
 while (supp_encodings[k].c_trans_enc != CE_UNSUPPORTED) {
	if (supp_encodings[k].c_trans_enc == chline) {
		def_encoding = k;
		b_putcfg_int(conf_name, "encoding", k);
		break;
							}
	k++;
							 }

 b_putcfg_int(conf_name, "encheader", fl_get_button(int_obj->Int_Header));
}
